ReActAgent

Struct ReActAgent 

pub struct ReActAgent { /* private fields */ }
A compiled ReAct agent graph.

This is a prebuilt graph that implements the ReAct (Reasoning + Acting) pattern:

  1. The model receives the conversation history and decides what to do
  2. If the model calls tools, they are executed and the results are added to the history
  3. The model sees the tool results and decides what to do next
  4. This continues until the model responds without tool calls (or max steps is reached)

Implementations

Source

impl ReActAgent

pub fn invoke( &self, input: &JsonValue, config: &RunnableConfig, ) -> Result<JsonValue, RunnableError>

Invoke the agent synchronously.

pub async fn ainvoke( &self, input: &JsonValue, config: &RunnableConfig, ) -> Result<JsonValue, RunnableError>

Invoke the agent asynchronously.