pub fn llm_response_to_json(response: Message) -> Result<Value, RunnableError>Expand description
Convert a model response into a state update JSON.
Wraps the response message in {"messages": [response]} format.
pub fn llm_response_to_json(response: Message) -> Result<Value, RunnableError>Convert a model response into a state update JSON.
Wraps the response message in {"messages": [response]} format.