BaseChatModel

Trait BaseChatModel 

pub trait BaseChatModel: Send + Sync {
    // Required methods
    fn name(&self) -> &str;
    fn invoke(
        &self,
        messages: &[Message],
        config: &RunnableConfig,
    ) -> Result<Message, ModelError>;
    fn bind_tools(&self, tools: Vec<ToolDef>) -> Box<dyn BaseChatModel>;

    // Provided methods
    fn ainvoke<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        messages: &'life1 [Message],
        config: &'life2 RunnableConfig,
    ) -> Pin<Box<dyn Future<Output = Result<Message, ModelError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait { ... }
    fn astream<'a>(
        &'a self,
        messages: &'a [Message],
        config: &'a RunnableConfig,
    ) -> MessageStream<'a> { ... }
}
A chat model that can generate responses.

Mirrors langchain-core’s BaseChatModel.

Required Methods

fn name(&self) -> &str

The name of the model.

fn invoke( &self, messages: &[Message], config: &RunnableConfig, ) -> Result<Message, ModelError>

Invoke the model with a list of messages and get a response.

fn bind_tools(&self, tools: Vec<ToolDef>) -> Box<dyn BaseChatModel>

Bind tools to the model for tool-calling support.

Provided Methods

fn ainvoke<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, messages: &'life1 [Message], config: &'life2 RunnableConfig, ) -> Pin<Box<dyn Future<Output = Result<Message, ModelError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Invoke the model asynchronously. Default delegates to sync invoke via block_in_place.

fn astream<'a>( &'a self, messages: &'a [Message], config: &'a RunnableConfig, ) -> MessageStream<'a>

Stream tokens from the model. Returns a stream of partial Message chunks.

Each yielded Message represents the accumulated content up to that point. For example, if the model generates “Hello world”, the stream might yield:

  • Message::ai("Hello")
  • Message::ai("Hello world")

The final item in the stream is the complete response (including tool calls if any).

Default implementation falls back to ainvoke (yields a single complete message).