Skip to main contentModule traits
Source - ClosureTool
- A simple tool implemented as a closure.
- LlmUsage
- Token usage information from an LLM API response.
- PreparedTools
- Result of
prepare_tools(): contains everything you need to work with tools. - ToolDef
- A tool definition that can be passed to a chat model.
- ModelError
- Error type for chat model operations.
- ToolError
- Error type for tool and model operations.
- BaseChatModel
- A chat model that can generate responses.
- BaseTool
- A tool that can be invoked by an agent.
- prepare_tools
- Prepare tools for use in a graph.
- MessageStream
- A stream of message chunks from a chat model.